==> babel-plugin-extract-gql-2.2.2.tgz: package/lib/index.js <==
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

var fs = require('fs');

var path = require('path');

var crypto = require('crypto');

var pkgDir = require('pkg-dir');

var pkgRoot = pkgDir.sync();
var outputFile = path.join(pkgRoot, 'gql-queries.json');

function appendJSON(json) {
  var data = {};

  if (fs.existsSync(outputFile)) {
    try {
      data = JSON.parse(fs.readFileSync(outputFile, 'utf8') || '');
    } catch (e) {
      console.log(e);
    }
  }

  Object.assign(data, json);
  fs.writeFileSync(outputFile, JSON.stringify(data, null, 2));
}

function extractGql(_ref) {
  var t = _ref.types;
  var queries = {};
  var varsTransformed = {};
  return {
    pre: function pre() {
      this.queries = {};
    },
    visitor: {
      TaggedTemplateExpression: function TaggedTemplateExpression(path) {
        var _path$node = path.node,
            tag = _path$node.tag,
            quasi = _path$node.quasi;
        if (tag.name !== 'persist') return; // if not the gql query, ignore

        if (quasi.quasis.length > 1) return; // if dynamic string, ignore

        var queryText = quasi.quasis[0].value.cooked.trim();
        var queryHash = crypto.createHash('sha256').update(queryText).digest('hex');
        var queryHashNode = t.stringLiteral(queryHash);
        this.queries[queryHash] = queryText;
        queries[queryHash] = queryText;
        var varName = path.parentPath.node.id.name;
        varsTransformed[varName] = true;
        path.replaceWith(queryHashNode);
      },
      CallExpression: function CallExpression(path) {
        var _path$node2 = path.node,
            callee = _path$node2.callee,
            args = _path$node2.arguments;

        var _args = _slicedToArray(args, 2),
            varNameArg = _args[0],
            optionsArg = _args[1];

        var varName = varNameArg.name; // if not a call to useQuery OR if is useQuery but not with a persisted query, ignore

        if (callee.name !== 'useQuery' || !varsTransformed[varName]) return;
        var optionsObj = optionsArg || t.objectExpression([]);
        optionsObj.properties.push(t.objectProperty(t.stringLiteral('persisted'), t.booleanLiteral(true)));
        if (!optionsArg) args.push(optionsObj);
      }
    },
    post: function post() {
      appendJSON(this.queries);
    }
  };
}

module.exports = extractGql;

==> babel-plugin-extract-gql-3.0.1.tgz: package/lib/index.js <==
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
var fs = require('fs');
var path = require('path');
var crypto = require('crypto');
var pkgDir = require('pkg-dir');
var pkgRoot = pkgDir.sync();
var outputFile = path.join(pkgRoot, 'gql-queries.json');
function appendJSON(json) {
  var data = {};
  if (fs.existsSync(outputFile)) {
    try {
      data = JSON.parse(fs.readFileSync(outputFile, 'utf8') || '');
    } catch (e) {
      console.log(e);
    }
  }
  Object.assign(data, json);
  fs.writeFileSync(outputFile, JSON.stringify(data, null, 2));
}
function extractGql(_ref) {
  var t = _ref.types;
  var queries = {};
  var varsTransformed = {};
  return {
    pre: function pre() {
      this.queries = {};
    },
    visitor: {
      TaggedTemplateExpression: function TaggedTemplateExpression(path) {
        var _path$node = path.node,
          tag = _path$node.tag,
          quasi = _path$node.quasi;
        if (tag.name !== 'persist') return; // if not the gql query, ignore
        if (quasi.quasis.length > 1) return; // if dynamic string, ignore

        var queryText = quasi.quasis[0].value.cooked.trim();
        var queryHash = crypto.createHash('sha256').update(queryText).digest('hex');
        var queryHashNode = t.stringLiteral(queryHash);
        this.queries[queryHash] = queryText;
        queries[queryHash] = queryText;
        var varName = path.parentPath.node.id.name;
        varsTransformed[varName] = true;
        path.replaceWith(queryHashNode);
      },
      CallExpression: function CallExpression(path) {
        var _path$node2 = path.node,
          callee = _path$node2.callee,
          args = _path$node2.arguments;
        var _args = _slicedToArray(args, 2),
          varNameArg = _args[0],
          optionsArg = _args[1];
        var varName = varNameArg.name;

        // if not a call to useQuery OR if is useQuery but not with a persisted query, ignore
        if (callee.name !== 'useQuery' || !varsTransformed[varName]) return;
        var optionsObj = optionsArg || t.objectExpression([]);
        optionsObj.properties.push(t.objectProperty(t.stringLiteral('persisted'), t.booleanLiteral(true)));
        if (!optionsArg) args.push(optionsObj);
      }
    },
    post: function post() {
      appendJSON(this.queries);
    }
  };
}
module.exports = extractGql;
